==> kubernetes-model-1.0.21-sources.jar: io/fabric8/kubernetes/api/model/TCPSocketActionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class TCPSocketActionBuilder extends TCPSocketActionFluent<TCPSocketActionBuilder> implements VisitableBuilder<TCPSocketAction,TCPSocketActionBuilder>{

     TCPSocketActionFluent<?> fluent;
public TCPSocketActionBuilder(){
    this(new TCPSocketAction());
}
public TCPSocketActionBuilder( TCPSocketActionFluent<?> fluent ){
    this(fluent, new TCPSocketAction());
}
public TCPSocketActionBuilder( TCPSocketActionFluent<?> fluent , TCPSocketAction instance ){
    this.fluent = fluent; fluent.withPort(instance.getPort()); 
}
public TCPSocketActionBuilder( TCPSocketAction instance ){
    this.fluent = this; this.withPort(instance.getPort()); 
}

public EditableTCPSocketAction build(){
    EditableTCPSocketAction buildable = new EditableTCPSocketAction(fluent.getPort());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
TCPSocketActionBuilder that = (TCPSocketActionBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.48-sources.jar: io/fabric8/kubernetes/api/model/TCPSocketActionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class TCPSocketActionBuilder extends TCPSocketActionFluentImpl<TCPSocketActionBuilder> implements VisitableBuilder<TCPSocketAction,TCPSocketActionBuilder>{

     TCPSocketActionFluent<?> fluent;
public TCPSocketActionBuilder(){
    this(new TCPSocketAction());
}
public TCPSocketActionBuilder( TCPSocketActionFluent<?> fluent ){
    this(fluent, new TCPSocketAction());
}
public TCPSocketActionBuilder( TCPSocketActionFluent<?> fluent , TCPSocketAction instance ){
    this.fluent = fluent; fluent.withPort(instance.getPort()); 
}
public TCPSocketActionBuilder( TCPSocketAction instance ){
    this.fluent = this; this.withPort(instance.getPort()); 
}

public EditableTCPSocketAction build(){
    EditableTCPSocketAction buildable = new EditableTCPSocketAction(fluent.getPort());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
TCPSocketActionBuilder that = (TCPSocketActionBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
